#
# spec file for package valgrind
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?!make_build:1}
%define make_build make -O %{?_smp_mflags} V=1 VERBOSE=1
%endif

# during building the major version of glibc is built into the suppression file
%define glibc_main_version %(getconf GNU_LIBC_VERSION | cut -d' ' -f2 | cut -d. -f1)
%define glibc_major_version %(getconf GNU_LIBC_VERSION | cut -d' ' -f2 | cut -d. -f2)
%global flavor client-headers%{nil}
%if "%{flavor}" == "client-headers"
%define psuffix  -client-headers-source
%endif
%bcond_without docs
Name:           valgrind%{?psuffix}
Version:        3.24.0
Release:        150600.3.3.1
Summary:        Memory Management Debugger
License:        GFDL-1.2-only AND GPL-2.0-or-later
Group:          Development/Tools/Debuggers
URL:            https://valgrind.org/
Source0:        https://sourceware.org/pub/valgrind/valgrind-%{version}.tar.bz2
Source1:        https://sourceware.org/pub/valgrind/valgrind-%{version}.tar.bz2.asc
Source2:        valgrind.keyring
# https://bugs.kde.org/show_bug.cgi?id=390553
# https://github.com/olafhering/valgrind/compare/olh-base-master...olh-fixes-master
Patch0:         valgrind.xen.patch
# bko#276780 missing implementation for PINSRD
Patch1:         VEX-x86-pinsrd.patch
Patch10:        dhat-use-datadir.patch
BuildRequires:  automake
BuildRequires:  pkgconfig
%if %{suse_version} == 1600 && !0%{?is_opensuse}
ExclusiveArch:  aarch64 x86_64 ppc64le s390x
%else
ExclusiveArch:  aarch64 %{ix86} x86_64 ppc ppc64 ppc64le s390x armv7l armv7hl armv6l armv6hl
%endif
%if "%{flavor}" == ""
Requires:       (glibc >= %{glibc_main_version}.%{glibc_major_version} with glibc < %{glibc_main_version}.%{lua:print(rpm.expand("%{glibc_major_version}")+1)})
Provides:       callgrind = %{version}
Obsoletes:      callgrind < %{version}
%if %{with docs}
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libxslt
%endif
%if 0%{?suse_version} < 1500
BuildRequires:  gcc8-c++
%global cpp_version -8
%else
BuildRequires:  gcc-c++
%endif
%if !0%{?disable_32bit}
%ifarch x86_64 ppc64
BuildRequires:  glibc-devel-32bit
%if 0%{?suse_version} < 1500
BuildRequires:  gcc8-c++-32bit
%else
BuildRequires:  gcc-c++-32bit
%endif
%endif
%endif
%endif

%description
Valgrind checks all memory operations in an application, like read,
write, malloc, new, free, and delete. Valgrind can find uses of
uninitialized memory, access to already freed memory, overflows,
illegal stack operations, memory leaks, and any illegal
new/malloc/free/delete commands. Another program in the package is
"cachegrind," a profiler based on the valgrind engine.

To use valgrind you should compile your application with "-g -O0"
compiler options. Afterwards you can use it with:

valgrind --tool=memcheck --sloppy-malloc=yes --leak-check=yes
--db-attach=yes my_application, for example.

More valgrind options can be listed via "valgrind --help". There is
also complete documentation in the %{_docdir}/valgrind/
directory. A debugged application runs slower and needs much more
memory, but is usually still usable. Valgrind is still in development,
but it has been successfully used to optimize several KDE applications.

%package devel
Summary:        Header files for for Valgrind
License:        GPL-2.0-or-later
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}
Requires:       %{name}-client-headers = %{version}

%description devel
This package contains the Valgrind header files.

%package -n valgrind-client-headers
Summary:        Header files for for Valgrind
# The client headers are permissively licensed under a BSD-style
# license. SPDX License Request filed.
# License:      BSD-3-Clause
License:        GFDL-1.2-only AND GPL-2.0-or-later
Group:          Development/Tools/Debuggers
Provides:       valgrind-devel:%{_includedir}/valgrind/valgrind.h
BuildArch:      noarch

%description -n valgrind-client-headers
This package contains the BSD-style licensed Valgrind header
files for inclusion into regular programs. The program can
detect if it is running under Valgrind and interact with the
Valgrind core and plugins.

%ifarch x86_64 ppc64 s390x
%package 32bit
Summary:        Memory Management Debugger
License:        GPL-2.0-or-later
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}
Provides:       valgrind:%{_libdir}/valgrind/32bit-core.xml

%description 32bit
Valgrind checks all memory operations in an application, like read,
write, malloc, new, free, and delete. Valgrind can find uses of
uninitialized memory, access to already freed memory, overflows,
illegal stack operations, memory leaks, and any illegal
new/malloc/free/delete commands. Another program in the package is
"cachegrind," a profiler based on the valgrind engine.

To use valgrind you should compile your application with "-g -O0"
compiler options. Afterwards you can use it with:

valgrind --tool=memcheck --sloppy-malloc=yes --leak-check=yes
--db-attach=yes my_application, for example.

More valgrind options can be listed via "valgrind --help". There is
also complete documentation in the %{_docdir}/valgrind/
directory. A debugged application runs slower and needs much more
memory, but is usually still usable. Valgrind is still in development,
but it has been successfully used to optimize several KDE applications.

%endif

%prep
%autosetup -p1 -n valgrind-%{version}

%build
%define _lto_cflags %{nil}
# The preloaded libs for intercepting rely on lazy binding (bsc#1208407)
export SUSE_ZNOW=0
export FLAGS="%{optflags}"
# not a good idea to build valgrind with fortify, as it does not link glibc
FLAGS="${FLAGS/-D_FORTIFY_SOURCE=2/}"
FLAGS="${FLAGS/-D_FORTIFY_SOURCE=3/}"
FLAGS="${FLAGS/-fstack-protector-strong/}"
FLAGS="${FLAGS/-fstack-protector/}"
# -m64 / -m32 is set explicitly everywhere, do not override it
FLAGS="${FLAGS/-m64/}"
export CFLAGS="$FLAGS"
export CXXFLAGS="$FLAGS"
export FFLAGS="$FLAGS"
export CXX="g++%{?cpp_version}"
export CC="gcc%{?cpp_version}"
autoreconf -fi

export GDB=%{_bindir}/gdb
%configure \
%ifnarch ppc64
    --enable-lto=yes \
%endif
%ifarch aarch64
    --enable-only64bit \
%endif
    %{nil}

%if "%{flavor}" == ""
%make_build
%if %{with docs}
pushd docs
    #make all-docs
    # building the docs needs network access at the moment :-(
    %make_build FAQ.txt man-pages html-docs
popd
%endif
%endif

%install
%if "%{flavor}" == ""
%make_install
rm %{buildroot}/%{_libdir}/valgrind/lib*.a # drop unreproducible unused files to fix boo#1118163

mkdir -p %{buildroot}/%{_defaultdocdir}
if test -d %{buildroot}%{_datadir}/doc/valgrind; then
     # Remove Postscript manual (20 MByte), there are PDF and HTML versions
     rm %{buildroot}%{_datadir}/doc/valgrind/valgrind_manual.ps
     mv %{buildroot}%{_datadir}/doc/valgrind %{buildroot}/%{_defaultdocdir}
fi
mkdir -p %{buildroot}%{_docdir}/%{name}

rm %{buildroot}/%{_includedir}/valgrind/{valgrind,cachegrind,callgrind,dhat,drd,helgrind,memcheck}.h

%else
install -m 755 -d %{buildroot}/%{_includedir}/valgrind
install -m 644 -t %{buildroot}/%{_includedir}/valgrind \
    include/valgrind.h \
    cachegrind/cachegrind.h \
    callgrind/callgrind.h \
    dhat/dhat.h \
    drd/drd.h \
    helgrind/helgrind.h \
    memcheck/memcheck.h
%endif

%check
%if "%{flavor}" == ""
# OBS doesn't have a z13
%ifnarch s390x %{arm}
# has too many spurious failures
# make %{?_smp_mflags} regtest
#patent pending self test
VALGRIND_LIB=$PWD/.in_place VALGRIND_LIB_INNER=$PWD/.in_place ./coregrind/valgrind  %{_bindir}/perl -wc tests/vg_regtest
%endif
%endif

%if "%{flavor}" == ""
%files devel
%dir %{_includedir}/valgrind
%{_includedir}/valgrind/config.h
%{_includedir}/valgrind/vki
%{_includedir}/valgrind/libvex*.h
%{_includedir}/valgrind/pub_tool*.h
%{_libdir}/pkgconfig/valgrind.pc

%files -n valgrind
%license COPYING COPYING.DOCS
%{_bindir}/*
%doc README* NEWS AUTHORS
%doc %{_defaultdocdir}/%{name}/*
%{_mandir}/*/*
%dir %{_libexecdir}/valgrind
%ifarch aarch64
%{_libexecdir}/valgrind/*-arm64-linux
%endif
%ifarch x86_64
%{_libexecdir}/valgrind/*-amd64-linux
%endif
%ifarch %{ix86}
%{_libexecdir}/valgrind/*-x86-linux
%endif
%ifarch ppc
%{_libexecdir}/valgrind/*-ppc32-linux
%endif
%ifarch ppc64
%{_libexecdir}/valgrind/*-ppc64be-linux
%endif
%ifarch ppc64le
%{_libexecdir}/valgrind/*-ppc64le-linux
%endif
%ifarch s390x
%{_libexecdir}/valgrind/*-s390x-linux
%endif
%ifarch %{arm}
%{_libexecdir}/valgrind/*-arm-linux
%endif
%dir %{_datadir}/valgrind
%{_datadir}/valgrind/dh_view*
%{_libexecdir}/valgrind/*-linux.so
%{_libexecdir}/valgrind/*.supp
%{_libexecdir}/valgrind/valgrind-monitor-def.py
%{_libexecdir}//valgrind/valgrind-monitor.py
%{_libexecdir}/valgrind/64bit-core.xml
%{_libexecdir}/valgrind/64bit-linux.xml
%{_libexecdir}/valgrind/64bit-sse.xml
%{_libexecdir}/valgrind/64bit-core-valgrind-s*.xml
%{_libexecdir}/valgrind/64bit-linux-valgrind-s*.xml
%{_libexecdir}/valgrind/64bit-sse-valgrind-s*.xml
%{_libexecdir}/valgrind/amd64-coresse-valgrind.xml
%{_libexecdir}/valgrind/amd64-linux-valgrind.xml
%{_libexecdir}/valgrind/power64-core-valgrind-s*.xml
%{_libexecdir}/valgrind/power64-core.xml
%{_libexecdir}/valgrind/power64-core2-valgrind-s*.xml
%{_libexecdir}/valgrind/power64-linux-valgrind-s*.xml
%{_libexecdir}/valgrind/power64-linux.xml
%{_libexecdir}/valgrind/64bit-avx-valgrind-s*.xml
%{_libexecdir}/valgrind/64bit-avx.xml
%{_libexecdir}/valgrind/amd64-avx-coresse-valgrind.xml
%{_libexecdir}/valgrind/amd64-avx-coresse.xml
%{_libexecdir}/valgrind/amd64-avx-linux-valgrind.xml
%{_libexecdir}/valgrind/amd64-avx-linux.xml
%{_libexecdir}/valgrind/mips64-cp0-valgrind-s*.xml
%{_libexecdir}/valgrind/mips64-cp0.xml
%{_libexecdir}/valgrind/mips64-cpu-valgrind-s*.xml
%{_libexecdir}/valgrind/mips64-cpu.xml
%{_libexecdir}/valgrind/mips64-fpu-valgrind-s*.xml
%{_libexecdir}/valgrind/mips64-fpu.xml
%{_libexecdir}/valgrind/mips64-linux-valgrind.xml
%{_libexecdir}/valgrind/mips64-linux.xml
%{_libexecdir}/valgrind/power-core-valgrind-s*.xml
%{_libexecdir}/valgrind/s390x-core64-valgrind-s*.xml
%{_libexecdir}/valgrind/s390x-core64.xml
%{_libexecdir}/valgrind/s390x-generic-valgrind.xml
%{_libexecdir}/valgrind/s390x-generic.xml
%{_libexecdir}/valgrind/s390x-linux64-valgrind-s*.xml
%{_libexecdir}/valgrind/s390x-linux64.xml
%{_libexecdir}/valgrind/s390x-vx-linux-valgrind.xml
%{_libexecdir}/valgrind/s390x-vx-linux.xml
# See https://bugzilla.suse.com/show_bug.cgi?id=1147071#c0
%{_libexecdir}/valgrind/s390-acr-valgrind-s*.xml
%{_libexecdir}/valgrind/s390-acr.xml
%{_libexecdir}/valgrind/s390-fpr-valgrind-s*.xml
%{_libexecdir}/valgrind/s390-fpr.xml
%{_libexecdir}/valgrind/s390-vx-valgrind-s*.xml
%{_libexecdir}/valgrind/s390-vx.xml

%ifarch x86_64 ppc64 s390x
%files 32bit
%endif

%ifarch %{ix86} x86_64
%if !0%{?disable_32bit}
%{_libexecdir}/valgrind/*-x86-linux
%endif
%endif

%ifarch ppc ppc64
%{_libexecdir}/valgrind/*-ppc32-linux
%endif
%{_libexecdir}/valgrind/mips-cp0-valgrind-s*.xml
%{_libexecdir}/valgrind/mips-cp0.xml
%{_libexecdir}/valgrind/mips-cpu-valgrind-s*.xml
%{_libexecdir}/valgrind/mips-cpu.xml
%{_libexecdir}/valgrind/mips-fpu-valgrind-s*.xml
%{_libexecdir}/valgrind/mips-fpu.xml
%{_libexecdir}/valgrind/mips-linux-valgrind.xml
%{_libexecdir}/valgrind/mips-linux.xml
%{_libexecdir}/valgrind/32bit-core.xml
%{_libexecdir}/valgrind/32bit-linux.xml
%{_libexecdir}/valgrind/32bit-sse.xml
%{_libexecdir}/valgrind/arm-core-valgrind-s*.xml
%{_libexecdir}/valgrind/arm-core.xml
%{_libexecdir}/valgrind/arm-vfpv3-valgrind-s*.xml
%{_libexecdir}/valgrind/arm-vfpv3.xml
%{_libexecdir}/valgrind/arm-with-vfpv3-valgrind.xml
%{_libexecdir}/valgrind/arm-with-vfpv3.xml
%{_libexecdir}/valgrind/32bit-core-valgrind-s*.xml
%{_libexecdir}/valgrind/32bit-linux-valgrind-s*.xml
%{_libexecdir}/valgrind/32bit-sse-valgrind-s*.xml
%{_libexecdir}/valgrind/i386-coresse-valgrind.xml
%{_libexecdir}/valgrind/i386-linux-valgrind.xml
%{_libexecdir}/valgrind/power-altivec-valgrind-s*.xml
%{_libexecdir}/valgrind/power-altivec.xml
%{_libexecdir}/valgrind/power-core.xml
%{_libexecdir}/valgrind/power-fpu-valgrind-s*.xml
%{_libexecdir}/valgrind/power-fpu.xml
%{_libexecdir}/valgrind/power-linux-valgrind-s*.xml
%{_libexecdir}/valgrind/power-linux.xml
%{_libexecdir}/valgrind/power-vsx-valgrind-s1.xml
%{_libexecdir}/valgrind/power-vsx-valgrind-s2.xml
%{_libexecdir}/valgrind/power-vsx.xml
%{_libexecdir}/valgrind/powerpc-altivec32l-valgrind.xml
%{_libexecdir}/valgrind/powerpc-altivec32l.xml
%{_libexecdir}/valgrind/powerpc-altivec64l-valgrind.xml
%{_libexecdir}/valgrind/powerpc-altivec64l.xml

%else

%files -n valgrind-client-headers
%dir %{_includedir}/valgrind
%{_includedir}/valgrind/cachegrind.h
%{_includedir}/valgrind/callgrind.h
%{_includedir}/valgrind/dhat.h
%{_includedir}/valgrind/drd.h
%{_includedir}/valgrind/helgrind.h
%{_includedir}/valgrind/memcheck.h
%{_includedir}/valgrind/valgrind.h
%endif

%changelog
* Thu Jan 30 2025 dmueller@suse.com
- update to 3.24.0 (jsc#PED-10260):
  * Bad file descriptor usage now generates a real error with
  - -track-fds=yes that is suppressible and shows up in the
    xml output with full execution backtrace. The warnings
    shown without using the option are deprecated and will be
    removed in a future valgrind version.
  * Ada name demangling is now supported in error messages.
- Bugs fixed:
  * 202770  open fd at exit --log-socket=127.0.0.1:1500 with
  - -track-fds=yes
  * 276780  An instruction in fftw (Fast Fourier Transform) is
    unhandled by valgrind: vex x86->IR: unhandled instruction bytes:
    0x66 0xF 0x3A 0x2
  * 311655  --log-file=FILE leads to apparent fd leak
  * 317127  Fedora18/x86_64 --sanity-level=3 : aspacem segment
    mismatch
  * 337388  fcntl works on Valgrind's own file descriptors
  * 377966  arm64 unhandled instruction dc zva392146  aarch64:
    unhandled instruction 0xD5380001 (MRS rT, midr_el1)
  * 391148  Unhandled AVX instruction vmovq %%xmm9,%%xmm1
  * 392146  aarch64: unhandled instruction 0xD5380001 (MRS rT,
    midr_el1)
  * 412377  SIGILL on cache flushes on arm64
  * 417572  vex amd64->IR: unhandled instruction bytes: 0xC5 0x79
    0xD6 0xED 0xC5
  * 440180  s390x: Failed assertion in disassembler
  * 444781  MIPS: wrong syscall numbers used
  * 447989  Support Armv8.2 SHA-512 instructions
  * 445235  Java/Ada/D demangling is probably broken
  * 453044  gbserver_tests failures in aarch64
  * 479661  Valgrind leaks file descriptors
  * 486180  [Valgrind][MIPS] 'VexGuestArchState' has no member
    named 'guest_IP_AT_SYSCALL'
  * 486293  memccpy false positives
  * 486569  linux inotify_init syscall wrapper missing POST entry
    in syscall_table
  * 487439  SIGILL in JDK11, JDK17
  * 487993  Alignment error when using Eigen with Valgrind and
  - m32
  * 488026  Use of `sizeof` instead of `strlen
  * 488379  --track-fds=yes errors that cannot be suppressed with
  - -xml-file=
  * 488441  Add tests for --track-fds=yes --xml=yes and fd
    suppression tests
  * 489040  massif trace change to show the location increasing
    the stack
  * 489088  Valgrind throws unhandled instruction bytes: 0xC5
    0x79 0xD6 0xE0 0xC5
  * 489338  arm64: Instruction fcvtas should round 322.5 to 323,
    but result is 322.
  * 489676  vgdb handle EINTR and EAGAIN more consistently
  * 490651  Stop using -flto-partition=one
  * 491394  (vgModuleLocal_addDiCfSI): Assertion
    'di->fsm.have_rx_map &&
  * di->fsm.rw_map_count' failed
  * 492210  False positive on x86/amd64 with ZF taken directly
    from addition
  * 492214  statx(fd, NULL, AT_EMPTY_PATH) is supported since
    Linux 6.11
  * but not supported in valgrind
  * 492422  Please support DRM_IOCTL_SYNCOBJ_HANDLE_TO_FD
  * 492663  Valgrind ignores debug info for some binaries
  * 493418  Add bad fd usage errors for --track-fds in
    ML_(fd_allowed)
  * 493454  Missing FUSE_COMPATIBLE_MAY_BLOCK markers
  * 493507  direct readlink syscall from PRE handler is
    incompatible with FUSE_COMPATIBLE_MAY_BLOCK
  * 493959  s390x: Fix regtest failure for none/tests/s390x/op00
  * 493970  s390x: Store/restore FPC upon helper call causes
    slowdown
  * 494252  s390x: incorrect disassembly for LOCHI and friends
  * 494960  Fixes and tweaks for gsl19test
  * 495278  PowerPC instruction dcbf should allow the L field
    values of 4, 6 on ISA 3.0 and earlier, just ignore
    the value
  * 495469  aligned_alloc and posix_memalign missing MALLOC_TRACE
    with returned pointer
  * 495470  s390x: 3.24.0.RC1 missing file and regtest failure
- parallel-lto.patch: drop, obsolete
* Sun Apr 28 2024 dmueller@suse.com
- update to 3.23.0 (jsc#PED-10260) (bsc#1243671):
  * Added ARM64 support for FreeBSD.
  * ARM64 now supports dotprod instructions (sdot/udot).
  * AMD64 better supports code build with -march=x86-64-v3.
    fused-multiple-add instructions (fma) are now emulated more
    accurately. And memcheck now handles __builtin_strcmp using 128/256
    bit vectors with sse4.1, avx/avx2.
  * S390X added support for NNPA (neural network processing assist)
    facility vector instructions VCNF, VCLFNH, VCFN, VCLFNL, VCRNF and
    NNPA (z16/arch14).
  * X86 recognizes new binutils-2.42 nop patterns.
- drop VEX-x86-nop-pattern.patch (upstream)
- drop armv6-support.diff (obsolete)
* Mon Feb  5 2024 schwab@suse.de
- VEX-x86-nop-pattern.patch: bko#478624 - Valgrind incompatibility with
  binutils-2.42 on x86 with new nop patterns (unhandled instruction bytes:
  0x2E 0x8D 0xB4 0x26)
* Fri Nov 24 2023 dmueller@suse.com
- update to 3.22.0: (jsc#PED-5442):
  * Memcheck now tests and warns about the values used for
    alignment and size. These apply to various functions: memalign,
    posix_memalign and aligned_alloc in C and various overloads
    of operators new and delete in C++. The kinds of error that can
    be detected are
  - invalid alignment, for instance the alignment is usually required
    to be a power of 2
  - mismatched alignment between aligned allocation and aligned
    deallocation
  - mismatched size when sized delete is used
  - bad size for functions that have implementation defined behaviour
    when the requested size is zero
  * many bug fixes, see https://valgrind.org/docs/manual/dist.news.html
* Wed Nov 15 2023 dmueller@suse.com
- remove 32bit support for ALP
* Tue Nov 14 2023 dmueller@suse.com
- add VEX-x86-pinsrd.patch (bko#276780)
* Wed Oct 25 2023 dmueller@suse.com
- remove buildrequires on 32bit packages
* Mon Oct 23 2023 dmueller@suse.com
- update filelist for 32bit disabled projects
* Mon Aug  7 2023 dmueller@suse.com
- use boolean / extended requires for glibc requires
* Thu May 18 2023 dmueller@suse.com
- update to 3.21.0:
  * When GDB is used to debug a program running under valgrind
    using the valgrind gdbserver, GDB will automatically load some
    python code provided in valgrind defining GDB front end
    commands corresponding to the valgrind monitor commands.
  * These GDB front end commands accept the same format as
    the monitor commands directly sent to the Valgrind
    gdbserver.
    These GDB front end commands provide a better integration
    in the GDB command line interface, so as to use for example
    GDB auto-completion, command specific help, searching for
    a command or command help matching a regexp, ...
    For relevant monitor commands, GDB will evaluate arguments
    to make the use of monitor commands easier.
    For example, instead of having to print the address of a
    variable to pass it to a subsequent monitor command, the
    GDB front end command will evaluate the address argument.
  * The vgdb utility now supports extended-remote protocol when
    invoked with --multi. In this mode the GDB run command is
    supported. Which means you don't need to run gdb and
    valgrind from different terminals.
  * The behaviour of realloc with a size of zero can now
    be changed for tools that intercept malloc. Those
    tools are memcheck, helgrind, drd, massif and dhat.
    Realloc implementations generally do one of two things
  - free the memory like free() and return NULL
    (GNU libc and ptmalloc).
  - either free the memory and then allocate a
    minimum sized block or just return the
    original pointer. Return NULL if the
    allocation of the minimum sized block fails
    (jemalloc, musl, snmalloc, Solaris, macOS).
  * When Valgrind is configured and built it will
    try to match the OS and libc behaviour. However
    if you are using a non-default library to replace
    malloc and family (e.g., musl on a glibc Linux or
    tcmalloc on FreeBSD) then you can use a command line
    option to change the behaviour of Valgrind:
  - -realloc-zero-bytes-frees=yes|no [yes on Linux glibc, no
    otherwise]
  * ==================== FIXED BUGS ====================
  * 241072  List tools in --help output
  * 327548  false positive while destroying mutex
  * 382034  Testcases build fixes for musl
  * 351857  confusing error message about valid command line
    option
  * 374596  inconsistent RDTSCP support on x86_64
  * 392331  Spurious lock not held error from inside
    pthread_cond_timedwait
  * 397083  Likely false positive "uninitialised value(s)" for
    __wmemchr_avx2 and __wmemcmp_avx2_movbe
  * 400793  pthread_rwlock_timedwrlock false positive
  * 419054  Unhandled syscall getcpu on arm32
  * 433873  openat2 syscall unimplemented on Linux
  * 434057  Add stdio mode to valgrind's gdbserver
  * 435441  valgrind fails to interpose malloc on musl 1.2.2 due
    to weak symbol name and no libc soname
  * 436413  Warn about realloc of size zero
  * 439685  compiler warning in callgrind/main.c
  * 444110  priv/guest_ppc_toIR.c:36198:31: warning: duplicated
    'if' condition.
  * 444487  hginfo test detects an extra lock inside data symbol
    "_rtld_local"
  * 444488  Use glibc.pthread.stack_cache_size tunable
  * 444568  drd/tests/pth_barrier_thr_cr fails on Fedora 38
  * 445743  "The impossible happened: mutex is locked
    simultaneously by two threads"
  * while using mutexes with priority inheritance and
    signals
  * 449309  Missing loopback device ioctl(s)
  * 459476  vgdb: allow address reuse to avoid "address already
    in use" errorsuse" errors
  * 460356  s390: Sqrt32Fx4 -- cannot reduce tree
  * 462830  WARNING: unhandled amd64-freebsd syscall: 474
  * 463027  broken check for MPX instruction support in assembler
  * 464103  Enhancement: add a client request to DHAT to mark
    memory to be histogrammed
  * 464476  Firefox fails to start under Valgrind
  * 464609  Valgrind memcheck should support Linux pidfd_open
  * 464680  Show issues caused by memory policies like selinux
    deny_execmem
  * 464859  Build failures with GCC-13 (drd tsan_unittest)
  * 464969  D language demangling
  * 465435  m_libcfile.c:66 (vgPlain_safe_fd): Assertion 'newfd
    >= VG_(fd_hard_limit)' failed.
  * 466104  aligned_alloc problems, part 1
  * 467036  Add time cost statistics for Regtest
  * 467482  Build failure on aarch64 Alpine
  * 467714  fdleak_* and rlimit tests fail when parent process
    has more than
  * 64 descriptors opened
  * 467839  Gdbserver: Improve compatibility of library directory
    name
  * 468401  [PATCH] Add a style file for clang-format
  * 468556  Build failure for vgdb
  * 468606  build: remove "Valgrind relies on GCC" check/output
  * 469097  ppc64(be) doesn't support SCV syscall instruction
  * n-i-bz  FreeBSD rfork syscall fail with EINVAL or ENOSYS
    rather than VG_(unimplemented)
- disable LTO on ppc64 (bsc#1205923)
* Wed Mar 29 2023 fvogt@suse.com
- Build without -z now (bsc#1208407)
* Wed Oct 26 2022 dmueller@suse.com
- update to 3.20.0:
  * The option "--vgdb-stop-at=event1,event2,..." accepts the new value abexit.
    This indicates to invoke gdbserver when your program exits abnormally
    (i.e. with a non zero exit code).
  * Fix Rust v0 name demangling.
  * The Linux rseq syscall is now implemented as (silently) returning ENOSYS.
  * Add FreeBSD syscall wrappers for __specialfd and __realpathat.
  * Remove FreeBSD dependencies on COMPAT10, which fixes compatibility with
    HardenedBSD
  * The option --enable-debuginfod=<no|yes> [default: yes] has been added on
    Linux.
  * More DWARF5 support as generated by clang14.
* Wed Aug  3 2022 dmueller@suse.com
- exclude client-headers from building for non-supported architectures
* Wed Apr 20 2022 adam.majer@suse.de
- fix build on SLE12
* Wed Apr 13 2022 dmueller@suse.com
- spec-cleaner suggested cleanups
- drop unnecessary procps buildrequires
* Tue Apr 12 2022 dmueller@suse.com
- update to 3.19.0 (bsc#1204685):
  * obsoletes backport 0001-arm64-Mismatch-detected-between-RDMA-and-atomics-fea.patch
    on older distributions
  * Fix Rust v0 name demangling.
  * The Linux rseq syscall is now implemented as (silently) returning ENOSYS.
  * Add FreeBSD syscall wrappers for __specialfd and __realpathat.
  * Remove FreeBSD dependencies on COMPAT10, which fixes compatibility with HardenedBSD
  * see https://valgrind.org/docs/manual/dist.news.html for list of bugfixes
- drop handle-rseq-syscall.patch: upstream
* Wed Mar  9 2022 dmueller@suse.com
- add upstream handle-rseq-syscall.patch to fix run with glibc 2.35
* Tue Nov  9 2021 viff3000@gmail.com
- update to 3.18.1 (jsc#SLE-18639):
  * 3.18.1 fixes a number of bugs and adds support for glibc-2.34, and for new
    platforms x86/FreeBSD and amd64/FreeBSD. Debuginfo reading is faster, and
    Rust demangling has been improved. For PPC64, ISA 3.1 support has been
    completed, and some newer ARM64 and S390 instructions are also supported.
* Sat Mar 20 2021 dmueller@suse.com
- update to 3.17.0 (jsc#SLE-18713):
  * 3.17.0 fixes a number of bugs and adds some functional changes: support for GCC
    11, Clang 11, DWARF5 debuginfo, the 'debuginfod' debuginfo server, and
    some new instructions for Arm64, S390 and POWER.  There are also some tool
    updates.
- drop s390x-z14-vector-support.patch
    0001-lmw-lswi-and-related-PowerPC-insns-aren-t-allowed-on.patch: upstream
* Mon Jan 11 2021 dmueller@suse.com
- add 0001-lmw-lswi-and-related-PowerPC-insns-aren-t-allowed-on.patch (bsc#1180412)
* Mon Jan  4 2021 dmueller@suse.com
- add s390x-z14-vector-support.patch (bsc#1180511)
* Sun Aug 16 2020 dmueller@suse.com
- update to 3.16.1 (jsc#SLE-13769):
  * PPC sync instruction L field should only be 2 bits in ISA 3.0
  * vex: the `impossible' happened: expr_is_guardable: unhandled expr
- remove 0001-Power-PC-Fix-extraction-of-the-L-field-for-sync-inst.patch (upstream)
* Fri Jun 19 2020 msuchanek@suse.de
- Use autopatch
  - Change armv6-support.diff to a/b format
* Fri Jun 19 2020 dmueller@suse.com
- update to 3.16.0:
  * Many bugfixes, too many to list here, see NEWS file
  - The implicit memcpy done by each call to realloc now counts towards the
    read and write counts of resized heap blocks, making those counts higher
    and more accurate.
  - cg_annotate's --auto and --show-percs options now default to 'yes', because
    they are usually wanted.
  - callgrind_annotate's --auto and --show-percs options now default to 'yes',
    because they are usually wanted.
  - The command option --collect-systime has been enhanced to specify
    the unit used to record the elapsed time spent during system calls.
    The command option now accepts the values no|yes|msec|usec|nsec,
    where yes is a synonym of msec.  When giving the value nsec, the
    system cpu time of system calls is also recorded.
  - Several memcheck options are now dynamically changeable.
    Use  valgrind --help-dyn-options  to list them.
  - The release 3.15 introduced a backward incompatible change for
    some suppression entries related to preadv and pwritev syscalls.
    When reading a suppression entry using the unsupported 3.14 format,
    valgrind will now produce a warning to say the suppression entry will not
    work, and suggest the needed change.
  - Significantly fewer false positive errors on optimised code generated by
    Clang and GCC.  In particular, Memcheck now deals better with the
    situation where the compiler will transform C-level "A && B" into "B && A"
    under certain circumstances (in which the transformation is valid).
    Handling of integer equality/non-equality checks on partially defined
    values is also improved on some architectures.
  - The exprimental Stack and Global Array Checking tool has been removed.
    It only ever worked on x86 and amd64, and even on those it had a
    high false positive rate and was slow.  An alternative for detecting
    stack and global array overruns is using the AddressSanitizer (ASAN)
    facility of the GCC and Clang compilers, which require you to rebuild
    your code with -fsanitize=address.
  - Option -T tells vgdb to output a timestamp in the vgdb information messages.
  - The gdbserver monitor commands that require an address and an optional
    length argument now accepts the alternate 'C like' syntax "address[length]".
    For example, the memcheck command "monitor who_points_at 0x12345678 120"
    can now also be given as "monitor who_points_at 0x12345678[120]".
  - 001-Add-newer-constants-for-prctl-syscall.patch
  0001-Fix-makefile-consistency-check.patch
  0001-s390x-Add-CPU-model-for-z15.patch
  0001-s390x-Add-models-z14-and-z14-ZR1.patch
  0001-s390x-Clean-up-s390-check-opcodes.pl.patch
  0001-Add-newer-constants-for-prctl-syscall.patch
  0002-Add-support-for-PR_CAPBSET_READ-and-_DROP-syscalls.patch:
  dropped as those patches were from upstream and are already in 3.16.0
  - add 0001-Power-PC-Fix-extraction-of-the-L-field-for-sync-inst.patch (bsc#1173135)
* Mon May 11 2020 dmueller@suse.com
- add dhat-use-datadir.patch:
  * move the dhat* scripts to datadir
* Wed Mar 25 2020 mliska@suse.cz
- Add parallel-lto.patch in order to make LTO LTRANS phase
  parallel. It will significantly improve build time.
* Thu Mar 12 2020 dmueller@suse.com
- add 0001-Fix-makefile-consistency-check.patch
  0001-s390x-Add-models-z14-and-z14-ZR1.patch
  0001-s390x-Clean-up-s390-check-opcodes.pl.patch
  0001-s390x-Add-CPU-model-for-z15.patch (bsc#1165834)
* Tue Jan 28 2020 guillaume.gardet@opensuse.org
- Disable %%check on %%arm as it never passed - boo#1130395
* Sun Jan 19 2020 stefan.bruens@rwth-aachen.de
- Add support for PR_CAPBSET_READ/DROP syscalls. Fixes false
  error messages with latest libcap 2.30.
  * 0001-Add-newer-constants-for-prctl-syscall.patch
  * 0002-Add-support-for-PR_CAPBSET_READ-and-_DROP-syscalls.patch
* Wed Nov 27 2019 dmueller@suse.com
- remove jit-register-unregister.diff (fails patch not applied check)
* Tue Oct 29 2019 dmueller@suse.com
- move s390-*xml files to main package (bsc#1147071)
* Tue Oct 22 2019 stefan.bruens@rwth-aachen.de
- Use _multibuild for creating the client-headers subpackage. As
  the headers are just copied over, the package has no substantial
  build dependencies.
* Thu Oct 17 2019 stefan.bruens@rwth-aachen.de
- Move the BSD-style licensed client headers to a subpackage.
  Packages only requiring e.g. valgrind.h during build no longer
  need the full valgrind and valgrind-devel packages then.
- Clean up documentation a bit:
  + use %%build_cond, drop unused docbook_4 BuildRequires
  + remove the Postscript Valgrind manual in favor of the PDF one.
- Add GFDL-1.2 to the License, relevant for man pages and Valgrind
  PDF/HTML manual.
* Wed May  8 2019 dmueller@suse.com
- update to 3.15.0 (fate#327402) (jira SLE-5861):
  3.15.0 is a feature release with many improvements and the usual collection of
  bug fixes.
  This release supports X86/Linux, AMD64/Linux, ARM32/Linux, ARM64/Linux,
  PPC32/Linux, PPC64BE/Linux, PPC64LE/Linux, S390X/Linux, MIPS32/Linux,
  MIPS64/Linux, ARM/Android, ARM64/Android, MIPS32/Android, X86/Android,
  X86/Solaris, AMD64/Solaris and AMD64/MacOSX 10.12.  There is also preliminary
  support for X86/macOS 10.13 and AMD64/macOS 10.13.
  * ==================== CORE CHANGES ===================
  * The XTree Massif output format now makes use of the information obtained
  when specifying --read-inline-info=yes.
  * amd64 (x86_64): the RDRAND and F16C insn set extensions are now supported.
  * ==================== TOOL CHANGES ====================
  * DHAT:
  - DHAT been thoroughly overhauled, improved, and given a GUI.  As a result,
    it has been promoted from an experimental tool to a regular tool.  Run it
    with --tool=dhat instead of --tool=exp-dhat.
  - DHAT now prints only minimal data when the program ends, instead writing
    the bulk of the profiling data to a file.  As a result, the --show-top-n
    and --sort-by options have been removed.
  - Profile results can be viewed with the new viewer, dh_view.html.  When
    a run ends, a short message is printed, explaining how to view the result.
  - See the documentation for more details.
  * Cachegrind:
  - cg_annotate has a new option, --show-percs, which prints percentages next
    to all event counts.
  * Callgrind:
  - callgrind_annotate has a new option, --show-percs, which prints percentages
    next to all event counts.
  - callgrind_annotate now inserts commas in call counts, and
    sort the caller/callee lists in the call tree.
  * Massif:
  - The default value for --read-inline-info is now "yes" on
    Linux/Android/Solaris. It is still "no" on other OS.
  * Memcheck:
  - The option --xtree-leak=yes (to output leak result in xtree format)
    automatically activates the option --show-leak-kinds=all, as xtree
    visualisation tools such as kcachegrind can in any case select what kind
    of leak to visualise.
  - There has been further work to avoid false positives.  In particular,
    integer equality on partially defined inputs (C == and !=) is now handled
    better.
- remove 0001-Bug-385411-s390x-Add-z13-vector-floating-point-suppo.patch
  0001-Bug-385411-s390x-Tests-and-internals-for-z13-vector-.patch
  0001-Bug-397187-s390x-Add-vector-register-support-for-vgd.patch
  0001-Bug-399444-s390x-Drop-unnecessary-check-in-s390_irge.patch
  0001-Bug-400490-s390x-Fix-register-allocation-for-VRs-vs-.patch
  0001-Bug-400491-s390x-Sign-extend-immediate-operand-of-LO.patch
  0001-Bug-402519-POWER-3.0-addex-instruction-incorrectly-i.patch
  0001-Bug-403552-s390x-Fix-vector-facility-bit-number.patch
  0001-s390x-more-fixes.patch
  Implement-emulated-system-registers.-Fixes-392146.patch (all upstream)
* Wed Apr 24 2019 mliska@suse.cz
- Disable LTO (boo#1133288).
* Tue Feb 19 2019 dmueller@suse.com
- add 0001-Bug-385411-s390x-Add-z13-vector-floating-point-suppo.patch
  0001-Bug-385411-s390x-Tests-and-internals-for-z13-vector-.patch
  0001-Bug-399444-s390x-Drop-unnecessary-check-in-s390_irge.patch
  0001-Bug-403552-s390x-Fix-vector-facility-bit-number.patch (bsc#1124111)
* Sat Feb  9 2019 schwab@suse.de
- Don't package files twice on ppc64
* Wed Jan 16 2019 msuchanek@suse.de
- Fix POWER9 addex instruction emulation (bsc#1121025).
  0001-Bug-402519-POWER-3.0-addex-instruction-incorrectly-i.patch
* Fri Jan 11 2019 dmueller@suse.com
- split into a -32bit subpackage, fix buildrequires for older distros
* Thu Dec  6 2018 bwiedemann@suse.com
- drop unreproducible unused .a files to make the package build
  reproducible (boo#1118163)
* Sun Nov 25 2018 olaf@aepfle.de
- update valgrind.xen.patch to branch bug390553-20181125-ddfc274b2
* Thu Nov 22 2018 dmueller@suse.com
- build against Toolchain module for SLE12
- add 0001-Bug-397187-s390x-Add-vector-register-support-for-vgd.patch
  0001-Bug-400490-s390x-Fix-register-allocation-for-VRs-vs-.patch,
  0001-Bug-400491-s390x-Sign-extend-immediate-operand-of-LO.patch,
  0001-s390x-more-fixes.patch,
  Implement-emulated-system-registers.-Fixes-392146.patch (FATE#326355)
- enable check (poo#36751)
* Wed Nov 21 2018 dmueller@suse.com
- update to 3.14.0 (bsc#1114575, FATE#326355):
  see http://www.valgrind.org/docs/manual/dist.news.html
  * The new option --keep-debuginfo=no|yes (default no) can be used to retain
    debug info for unloaded code.  This allows saved stack traces (e.g. for
    memory leaks) to include file/line info for code that has been dlclose'd (or
    similar).  See the user manual for more information and known limitations.
  * Ability to specify suppressions based on source file name and line number.
  * Majorly overhauled register allocator.  No end-user changes, but the JIT
    generates code a bit more quickly now.
  * Preliminary support for macOS 10.13 has been added.
  * mips: support for MIPS32/MIPS64 Revision 6 has been added.
  * mips: support for MIPS SIMD architecture (MSA) has been added.
  * mips: support for MIPS N32 ABI has been added.
  * s390: partial support for vector instructions (integer and string) has been
    added.
  * Helgrind: Addition of a flag
  - -delta-stacktrace=no|yes [yes on linux amd64/x86]
    which specifies how full history stack traces should be computed.
    Setting this to =yes can speed up Helgrind by 25%% when using
  - -history-level=full.
  * Memcheck: reduced false positive rate for optimised code created by Clang 6
    / LLVM 6 on x86, amd64 and arm64.  In particular, Memcheck analyses code
    blocks more carefully to determine where it can avoid expensive definedness
    checks without loss of precision.  This is controlled by the flag
  - -expensive-definedness-checks=no|auto|yes [auto].
  * Valgrind is now buildable with link-time optimisation (LTO).  A new
    configure option --enable-lto=yes allows building Valgrind with LTO.  If the
    toolchain supports it, this produces a smaller/faster Valgrind (up to 10%%).
    Note that if you are doing Valgrind development, --enable-lto=yes massively
    slows down the build process.
- remove epoll-wait-fix.patch,
  Fix-access-to-time-base-register-to-return-64-bits.patch,
  0001-Accept-read-only-PT_LOAD-segments-and-.rodata.patch (upstream),
* Tue Sep 25 2018 msuchanek@suse.com
- valgrind truncates powerpc timebase to 32-bits (bsc#1109589).
  Fix-access-to-time-base-register-to-return-64-bits.patch
* Thu Sep 13 2018 dmueller@suse.com
- valgrind.xen.patch: refresh
* Tue Aug 28 2018 stefan.bruens@rwth-aachen.de
- Filter out -m64 from optflags, breaks build of 32 bit parts
- Cleanup, remove suse_version < 1100 conditionals
- Use %%license for COPYING, COPYING.DOCS
* Mon Aug 27 2018 stefan.bruens@rwth-aachen.de
- Fix missing debuginfo with current binutils, boo#1103239
  0001-Accept-read-only-PT_LOAD-segments-and-.rodata.patch
* Fri Jun  8 2018 mbrugger@suse.com
- ad Implement-emulated-system-registers.-Fixes-392146.patch (bsc#1086543)
* Thu Feb 22 2018 olaf@aepfle.de
- add valgrind.xen.patch to handle Xen 4.10 (fate#321394, fate#322686)
* Mon Oct 30 2017 dmueller@suse.com
- add epoll-wait-fix.patch (bsc#1064958)
* Sun Jun 25 2017 dmueller@suse.com
- update to 3.13.0 (fate#321455):
  - remove fix-ppcl64-clobber-list.patch
  3.13.0 is a feature release with many improvements and the
  usual collection of bug fixes.
  See http://valgrind.org/docs/manual/dist.news.html
* Tue Apr 25 2017 mliska@suse.cz
- Add fix-ppcl64-clobber-list.patch: fix clobber list on ppcl64le,
  it's backport of upstream patch.
* Tue Dec 27 2016 foss@grueninger.de
- update to 3.12.0 (bsc#1017016, FATE#321455, bsc#987635, CVE-2016-6131)
  * 3.12.0 is a feature release with many improvements and the usual
  collection of bug fixes. The full changelog can be found at
  http://valgrind.org/docs/manual/dist.news.html
  or
  /usr/share/doc/packages/valgrind/NEWS
- droped patches which are part of the release:
  gcc5.patch, r15702.diff, r15792.diff, r15802.diff, svn-r15766.patch,
  vex-r3197.diff, vex-r3210.diff, vex-r3213.diff
* Thu Oct 20 2016 stefan.bruens@rwth-aachen.de
- add vex-r3213.diff (kde#356393)
* Sat May 28 2016 dmueller@suse.com
- add vex-r3197.diff (bsc#981447)
* Wed Apr 20 2016 jslaby@suse.com
- The previous did not help, remove -strong first.
* Tue Apr 19 2016 meissner@suse.com
- also remove -fstack-protector-strong from the CFLAGS
* Fri Apr  1 2016 dmueller@suse.com
- add r15702.diff, r15792.diff, vex-r3210.diff, r15802.diff (fate#319608)
* Mon Feb 22 2016 schwab@suse.de
- glibc-version.patch: removed, no longer needed
* Mon Feb 15 2016 dmueller@suse.com
- update to 3.11.0 (fate#319608):
  * 3.11.0 is a feature release with many improvements and the usual
  collection of bug fixes.
- replace gcc-version.patch with gcc5.patch: This is the upstream
  version
- drop valgrind-linux-4.0.patch: merged upstream
- add svn-r15766.patch: Fix valgrind with recent kernels
- jit-register-unregister.diff commented out, needs porting
* Thu Aug  6 2015 schwab@suse.de
- glibc-version.patch: Add support for glibc 2.22.
* Fri Apr 24 2015 dimstar@opensuse.org
- Add valgrind-linux-4.0.patch: Fix build with linux kernel 4.0+.
  Taken from svn, rev 14955.
* Thu Apr  2 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update to 3.10.1
  * bugfix release (for full list of solved issues see NEWS file)
* Thu Feb 12 2015 rguenther@suse.com
- gcc-version.patch: Add support for GCC 5.
* Mon Feb  9 2015 schwab@suse.de
- glibc-version.patch: Add support for glibc 2.21.
* Tue Sep 16 2014 schwab@suse.de
- glibc-2.19.patch: already upstream, so remove
- Fix file list
* Tue Sep 16 2014 dmueller@suse.com
- update to 3.10.0:
  * Support for the 64-bit ARM Architecture (AArch64 ARMv8).  This port
    is mostly complete, and is usable, but some SIMD instructions are as
    yet unsupported.
  * Support for little-endian variant of the 64-bit POWER architecture.
  * Support for Android on MIPS32.
  * Support for 64bit FPU on MIPS32 platforms.
  * Both 32- and 64-bit executables are supported on MacOSX 10.8 and 10.9.
  * Configuration for and running on Android targets has changed.
    See README.android in the source tree for details.
  - drop VEX-r2803.diff, VEX-r2808.diff, VEX-r2816.diff, VEX-r2858.diff,
  VEX-r2904.diff, VEX-r2910.diff, VEX-r2914.diff, VEX-r2915.diff,
  VEX-r2916.diff, aarch64-VEX-support.diff, aarch64-support.diff,
  r13767.diff, r13770.diff, r14184.diff, r14238.diff, r14239.diff,
  r14240.diff, r14246.diff, r2798.diff, valgrind-r13948.diff
* Sun Aug 17 2014 dmueller@suse.com
- update for ppc64le support (bnc#880334):
  - drop: valgrind-3.9.0-merge.patches.from.Paul.McKenney.patch,
  valgrind-3.9.0-ppc64le-abiv2.patch
  - add: VEX-r2803.diff, VEX-r2808.diff, VEX-r2816.diff
  VEX-r2904.diff, VEX-r2910.diff, VEX-r2914.diff, VEX-r2915.diff,
  VEX-r2916.diff, r13767.diff, r13770.diff, r14184.diff, r14238.diff,
  r14239.diff, r14240.diff, r14246.diff
* Sat Jul 26 2014 schwab@suse.de
- Fix patch conflicts.
* Wed Jun 18 2014 dmueller@suse.com
- add VEX-r2858.diff, valgrind-r13948.diff for (bnc#883157)
* Sun May 18 2014 schwab@suse.de
- Update aarch64-support.diff, aarch64-VEX-support.diff from svn
* Thu Apr 24 2014 dmueller@suse.com
- add aarch64-support.diff, aarch64-VEX-support.diff: aarch64 support
* Tue Feb 18 2014 dmueller@suse.com
- added patches:
  * r2798.diff
* Tue Feb 11 2014 schwab@suse.de
- glibc-2.19.patch: add support for glibc 2.19
* Mon Jan 13 2014 normand@linux.vnet.ibm.com
- add support of ppc64le architecture
- added patches:
  * valgrind-3.9.0-merge.patches.from.Paul.McKenney.patch
  * valgrind-3.9.0-ppc64le-abiv2.patch
* Fri Jan  3 2014 dmueller@suse.com
- add armv6-support.diff: Add support for armv6hl
* Wed Nov  6 2013 burnus@net-b.de
- update to 3.9.0:
  * Support for Intel AVX2 instructions.  This is available only on 64
  bit code.
  * Support for POWER8 (Power ISA 2.07) instructions.
  * Initial support for Intel Transactional Synchronization Extensions,
  both RTM and HLE.
  * Initial support for Hardware Transactional Memory on POWER.
  * Improvements in handling of vectorised code, leading to
  significantly fewer false error reports.  You need to use the flag
  - -partial-loads-ok=yes to get the benefits of these changes.
  * Better control over the leak checker.  It is now possible to
  specify which leak kinds (definite/indirect/possible/reachable)
  should be displayed.
  * Reduced "possible leak" reports from the leak checker by the use
  of better heuristics.
  * Better control of stacktrace acquisition for heap-allocated
  blocks.
  * Better reporting of leak suppression usage.
  * New and modified GDB server monitor features.
  * New flag --sigill-diagnostics to control whether a diagnostic
  message is printed when the JIT encounters an instruction it can't
  translate.
  * The maximum amount of memory that Valgrind can use on 64 bit
  targets has been increased from 32GB to 64GB.
  * Additional smaller new features and many bug fixes.
- Remove obsolete raise-segnames-limit.diff,
  valgrind-glibc-2.17.patch and valgrind-glibc-2.18.patch.
* Tue Aug 13 2013 schwab@suse.de
- valgrind-glibc-2.18.patch: add support for glibc 2.18
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Mon Dec 31 2012 idonmez@suse.com
- Fix last patch
* Mon Dec 31 2012 idonmez@suse.com
- Add valgrind-glibc-2.17.patch to fix compilation with glibc 2.17
* Thu Oct  4 2012 dmueller@suse.com
- raise seglimit to make it more useful for some apps
* Thu Sep 20 2012 burnus@net-b.de
- update to 3.8.1 (bnc#776211):
  * Fixes some assertion failures.
  * Support for some missing instructions on ARM.
  * Support instructions MOVAPS and TZCNT.
  * Bug fixes.
* Wed Sep  5 2012 dmueller@suse.com
- update to 3.8.0 (FATE#314090):
  * Support for MIPS32 platforms running Linux.  Valgrind has been
  tested on MIPS32 and MIPS32r2 platforms running different Debian
  Squeeze and MeeGo distributions.  Both little-endian and big-endian
  cores are supported.  The tools Memcheck, Massif and Lackey have
  been tested and are known to work. See README.mips for more details.
  * Preliminary support for Android running on x86.
  * Preliminary (as-yet largely unusable) support for MacOSX 10.8.
  * Support for Intel AVX instructions and for AES instructions.  This
  support is available only for 64 bit code.
  * Support for POWER Decimal Floating Point instructions.
  * Non-libc malloc implementations are now supported.  This is useful
  for tools that replace malloc (Memcheck, Massif, DRD, Helgrind).
  Using the new option --soname-synonyms, such tools can be informed
  that the malloc implementation is either linked statically into the
  executable, or is present in some other shared library different
  from libc.so.  This makes it possible to process statically linked
  programs, and programs using other malloc libraries, for example
  TCMalloc or JEMalloc.
  * For tools that provide their own replacement for malloc et al, the
  option --redzone-size=<number> allows users to specify the size of
  the padding blocks (redzones) added before and after each client
  allocated block.  Smaller redzones decrease the memory needed by
  Valgrind.  Bigger redzones increase the chance to detect blocks
  overrun or underrun.  Prior to this change, the redzone size was
  hardwired to 16 bytes in Memcheck.
  * Memcheck:
  - The leak_check GDB server monitor command now can
    control the maximum nr of loss records to output.
  - Reduction of memory use for applications allocating
    many blocks and/or having many partially defined bytes.
  - Addition of GDB server monitor command 'block_list' that lists
    the addresses/sizes of the blocks of a leak search loss record.
  - Addition of GDB server monitor command 'who_points_at' that lists
    the locations pointing at a block.
  - If a redzone size > 0 is given, VALGRIND_MALLOCLIKE_BLOCK now will
    detect an invalid access of these redzones, by marking them
    noaccess.  Similarly, if a redzone size is given for a memory
    pool, VALGRIND_MEMPOOL_ALLOC will mark the redzones no access.
    This still allows to find some bugs if the user has forgotten to
    mark the pool superblock noaccess.
  - Performance of memory leak check has been improved, especially in
    cases where there are many leaked blocks and/or many suppression
    rules used to suppress leak reports.
  - Reduced noise (false positive) level on MacOSX 10.6/10.7, due to
    more precise analysis, which is important for LLVM/Clang
    generated code.  This is at the cost of somewhat reduced
    performance.  Note there is no change to analysis precision or
    costs on Linux targets.
  * DRD:
  - Added even more facilities that can help finding the cause of a data
    race, namely the command-line option --ptrace-addr and the macro
    DRD_STOP_TRACING_VAR(x). More information can be found in the manual.
  - Fixed a subtle bug that could cause false positive data race reports.
  * The C++ demangler has been updated so as to work well with C++
  compiled by up to at least g++ 4.6.
  * Tool developers can make replacement/wrapping more flexible thanks
  to the new option --soname-synonyms.  This was reported above, but
  in fact is very general and applies to all function
  replacement/wrapping, not just to malloc-family functions.
  * Round-robin scheduling of threads can be selected, using the new
  option --fair-sched= yes.  Prior to this change, the pipe-based
  thread serialisation mechanism (which is still the default) could
  give very unfair scheduling.  --fair-sched=yes improves
  responsiveness of interactive multithreaded applications, and
  improves repeatability of results from the thread checkers Helgrind
  and DRD.
  * For tool developers: support to run Valgrind on Valgrind has been
  improved.  We can now routinely Valgrind on Helgrind or Memcheck.
  * gdbserver now shows the float shadow registers as integer
  rather than float values, as the shadow values are mostly
  used as bit patterns.
  * Increased limit for the --num-callers command line flag to 500.
  * Performance improvements for error matching when there are many
  suppression records in use.
  * Improved support for DWARF4 debugging information (bug 284184).
  * Initial support for DWZ compressed Dwarf debug info.
  * Improved control over the IR optimiser's handling of the tradeoff
  between performance and precision of exceptions.  Specifically,
  - -vex-iropt-precise-memory-exns has been removed and replaced by
  - -vex-iropt-register-updates, with extended functionality.  This
  allows the Valgrind gdbserver to always show up to date register
  values to GDB.
  * Modest performance gains through the use of translation chaining for
  JIT-generated code.
* Fri Aug 17 2012 burnus@net-b.de
- Support TZCNT/LZCNT instructions, generated by GCC 4.8,
  by falling back to BSF/BSR. (bnc#776211)
* Sun Jul 22 2012 aj@suse.de
- Support glibc 2.16.
* Mon Jun  4 2012 dmueller@suse.com
- arch is now armv7hl
* Tue May 15 2012 sndirsch@suse.com
- add "BuildRequires: pkgconfig" so the provides for
  "pkgconfig(valgrind)" gets created again
* Thu May 10 2012 vuntz@opensuse.org
- Remove xorg-x11-devel BuildRequires: I can only guess it was
  there to make sure the xfree supp files are used, but they are
  used anyway by default. This helps resolve a build loop between
  libdrm and valgrind.
* Thu Apr 26 2012 joop.boonen@opensuse.org
- Added patch valgrind-3.7.0-automake-1.11.2.patch to fix automake issue
  * See https://bugs.kde.org/show_bug.cgi?id=290719
* Thu Dec 29 2011 dmueller@suse.de
- fix build against glibc 2.15
* Mon Dec 19 2011 adrian@suse.de
- build only on armv7l, not armv5
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Nov  9 2011 dmueller@suse.de
- update to 3.7.0 (bnc#724215):
  * Support for IBM z/Architecture (s390x) running Linux.  Valgrind can
  analyse 64-bit programs running on z/Architecture.  Most user space
  instructions up to and including z10 are supported.
  See README.s390 for more details.
  * Support for the IBM Power ISA 2.06 (Power7 instructions)
  * Further solidification of support for SSE 4.2 in 64-bit mode
  * Memcheck:
  * - reduction of memory use in some circumstances
  * - improved handling of freed memory for finding more errors
  * - fix of a longstanding bug that could cause false negatives
  * Helgrind:
  * - Helgrind: performance improvements and major memory use reductions
  * GDB server: Valgrind now has an embedded GDB server.  That means it
  is possible to control a Valgrind run from GDB, doing all the usual
  things that GDB can do (single stepping, breakpoints, examining
  data, etc).  Tool-specific functionality is also available.
  * Over 160 bugs have been fixed.
* Mon Oct 24 2011 ro@suse.de
- fix build on ppc (32bit)
* Sun Oct  2 2011 dmueller@suse.de
- enable build on %%%%arm
* Fri Aug 19 2011 dmueller@suse.de
- fix build against glibc 2.14
- require the right version of glibc at runtime (part of fix for bnc#700362)
* Tue Jul  5 2011 aj@suse.de
- Support Linux kernel 3.x (bnc#724215)
* Wed Jun 22 2011 dmueller@suse.de
- fix merge error
* Sat Jun 18 2011 dmueller@suse.de
- Improve Valgrind POWER6 and POWER7/P7 support (bnc#700358)
* Tue May 17 2011 stefan.bruens@rwth-aachen.de
- revert removal for gcc-32bit requirement, breaks valgrinding
  32bit code on 64bit archs (bnc#705405)
* Mon Apr 11 2011 dmueller@suse.de
- fix testsuite for s390 (kde#264800, kde#265762, kde#253206)
- Add folding rules for Clz32 and Clz64 (kde#243404)
- Refresh s390x port (kde#243404)
* Wed Mar 16 2011 dmueller@suse.de
- update to 3.6.1 (bnc#679106):
  3.6.1 is a bug fix release.  It adds support for some SSE4
  instructions that were omitted in 3.6.0 due to lack of time.  Initial
  support for glibc-2.13 has been added.  A number of bugs causing
  crashing or assertion failures have been fixed.
* Fri Oct 22 2010 dmueller@suse.de
- update to 3.6.0:
  3.6.0 is a feature release with many significant improvements and the
  usual collection of bug fixes. See the NEWS file for details.
* Thu Oct 21 2010 dmueller@suse.de
- apparently gcc-32bit does not exist on old code streams, but
  it seems to work without it as well
* Wed Oct 20 2010 dmueller@suse.de
- disable building docs until I find a way to build them without
  network access
* Wed Oct 13 2010 dmueller@suse.de
- add s390x port (FATE#310036)
- update to 3.6.0 snapshot:
  - Valgrind runs much faster when the --smc-check=all option is given.
  - Cachegrind has a new processing script, cg_diff, which finds the
    difference between two profiles.  It's very useful for evaluating the
    performance effects of a change in a program.
    Related to this change, the meaning of cg_annotate's (rarely-used)
  - -threshold option has changed; this is unlikely to affect many people, if
    you do use it please see the user manual for details.
  - Callgrind now can do branch prediction simulation, similar to Cachegrind.
    In addition, it optionally can count the number of executed global bus events.
    Both can be used for a better approximation of a "Cycle Estimation" as
    derived event (you need to update the event formula in KCachegrind yourself).
  - Cachegrind and Callgrind now refer to the LL (last-level) cache rather
    than the L2 cache.  This is to accommodate machines with three levels of
    caches -- if Cachegrind/Callgrind auto-detects the cache configuration of
    such a machine it will run the simulation as if the L2 cache isn't
    present.  This means the results are less likely to match the true result
    for the machine, but Cachegrind/Callgrind's results are already only
    approximate, and should not be considered authoritative.  The results are
    still useful for giving a general idea about a program's locality.
  - Massif has a new option, --pages-as-heap, which is disabled by default.
    When enabled, instead of tracking allocations at the level of heap blocks
    (as allocated with malloc/new/new[]), it instead tracks memory allocations
    at the level of memory pages (as mapped by mmap, brk, etc).  Each mapped
    page is treated as its own block.  Interpreting the page-level output is
    harder than the heap-level output, but this option is useful if you want
    to account for every byte of memory used by a program.
  - Added new memcheck command-line option --show-possibly-lost.
  - Support for analyzing programs running under Wine with has been improved.
    The header files <valgrind/valgrind.h>, <valgrind/memcheck.h> and
    <valgrind/drd.h> can now be used in Windows-programs compiled with MinGW
    or one of the Microsoft Visual Studio compilers.
  - DRD does now have two new command-line options: --free-is-write and
  - -trace-alloc. The former allows to detect reading from already freed
    memory, and the latter allows to trace all memory allocations and
    deallocations.
  - Several new annotations have been added in DRD: custom barrier
    implementations can now be annotated and benign races on static variables
    too.
  - The happens before / happens after annotations in DRD have been made more
    powerful such that these can now also be used to annotate e.g. a smart
    pointer implementation.
* Thu Sep 23 2010 dmueller@suse.de
- increase stack size (bnc#640793)
* Fri May  7 2010 dmueller@suse.de
- fix build for ppc64
* Mon Apr 26 2010 dmueller@suse.de
- handle pthread apps better (bnc#599585)
- prefer CFI for better stack unwinding (bnc#559061)
* Fri Mar 26 2010 dmueller@suse.de
- handle inotify_init1 (bnc#558964)
* Wed Jan  6 2010 dmueller@suse.de
- fix build against glibc 2.11
* Wed Dec  2 2009 dmueller@suse.de
- update and reenable jit-register-unregister.diff
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Sep  8 2009 dmueller@suse.de
- update to 3.5.0:
  * Support for glibc 2.10, gcc 4.5 has been added.
  * Improvements and simplifications to Memcheck's leak checker.
  * Clarification and simplifications in various aspects of Valgrind's
    text output.
  * XML output for Helgrind and Ptrcheck.
  * Performance and stability improvements for Helgrind and DRD.
  * Genuinely atomic support for x86/amd64/ppc atomic instructions.
  * A new experimental tool, BBV, useful for computer architecture
    research.
  * Improved Wine support, including ability to read Windows PDB
    debuginfo.
* Fri Mar 13 2009 dmueller@suse.de
- update to 3.4.1 (bnc#479701):
  * 3.4.1 is a bug-fix release that fixes some regressions and
  assertion failures in debug info reading in 3.4.0, most notably
  incorrect stack traces on amd64-linux on older (glibc-2.3 based)
  systems. Various other debug info problems are also fixed. A
  number of bugs in the exp-ptrcheck tool introduced in 3.4.0
  have been fixed.
* Fri Jan 23 2009 dmueller@suse.de
- update to 3.4.0:
  * http://www.valgrind.org/docs/manual/dist.news.html
* Sat Nov 22 2008 dmueller@suse.de
- update suppressions
* Wed Nov 19 2008 dmueller@suse.de
- fix .valgrindrc reading vulnerability (CVE-2008-4865, bnc#445013)
- add support for glibc 2.9
* Wed Nov  5 2008 dmueller@suse.de
- add syscall wrappers for pipe2
* Tue Jun 24 2008 schwab@suse.de
- Add fadvice64 wrapper.
* Sun Jun 22 2008 dmueller@suse.de
- update to 3.3.1:
    n-i-bz  Massif segfaults at exit
    n-i-bz  Memcheck asserts on Altivec code
    n-i-bz  fix sizeof bug in Helgrind
    n-i-bz  check fd on sys_llseek
    n-i-bz  update syscall lists to kernel 2.6.23.1
    n-i-bz  support sys_sync_file_range
    n-i-bz  handle sys_sysinfo, sys_getresuid, sys_getresgid on ppc64-linux
    n-i-bz  intercept memcpy in 64-bit ld.so's
    n-i-bz  Fix wrappers for sys_{futimesat,utimensat}
    n-i-bz  Minor false-error avoidance fixes for Memcheck
    n-i-bz  libmpiwrap.c: add a wrapper for MPI_Waitany
    n-i-bz  helgrind support for glibc-2.8
    n-i-bz  partial fix for mc_leakcheck.c:698 assert:
    'lc_shadows[i]->data + lc_shadows[i] ...
    n-i-bz  Massif/Cachegrind output corruption when programs fork
    n-i-bz  register allocator fix: handle spill stores correctly
    n-i-bz  add support for PA6T PowerPC CPUs
    126389  vex x86->IR: 0xF 0xAE (FXRSTOR)
    158525  ==126389
    152818  vex x86->IR: 0xF3 0xAC (repz lodsb)
    153196  vex x86->IR: 0xF2 0xA6 (repnz cmpsb)
    155011  vex x86->IR: 0xCF (iret)
    155091  Warning [...] unhandled DW_OP_ opcode 0x23
    156960  ==155901
    155528  support Core2/SSSE3 insns on x86/amd64
    155929  ms_print fails on massif outputs containing long lines
    157665  valgrind fails on shmdt(0) after shmat to 0
    157748  support x86 PUSHFW/POPFW
    158212  helgrind: handle pthread_rwlock_try{rd,wr}lock.
    158425  sys_poll incorrectly emulated when RES==0
    158744  vex amd64->IR: 0xF0 0x41 0xF 0xC0 (xaddb)
    160907  Support for a couple of recent Linux syscalls
    161285  Patch -- support for eventfd() syscall
    161378  illegal opcode in debug libm (FUCOMPP)
    160136  ==161378
    161487  number of suppressions files is limited to 10
    162386  ms_print typo in milliseconds time unit for massif
    161036  exp-drd: client allocated memory was never freed
    162663  signalfd_wrapper fails on 64bit linux
* Sun Apr 27 2008 dmueller@suse.de
- update glibc 2.8 support
* Sun Dec 16 2007 dmueller@suse.de
- readd deprecated #define's (#348337)
* Tue Dec 11 2007 dmueller@suse.de
- update to 3.3.0 (final):
  * last minute bugfixes
* Thu Dec  6 2007 dmueller@suse.de
- update jit-support patch
* Mon Dec  3 2007 dmueller@suse.de
- update to 3.3.0 RC1:
  - Helgrind works again
  - Massif has been majorly overhauled
  - Cachegrind now does branch-prediction profiling
  - New experimental tools Omega and DRD
  - Many small refinements to stability, scalability and performance
  - Somewhat restructured documentation
  - Many bug fixes
* Mon Nov 26 2007 dmueller@suse.de
- fix build against glibc 2.7
* Fri Sep 14 2007 dmueller@suse.de
- fix divisions by zero in massif (#310234)
* Wed Sep 12 2007 dmueller@suse.de
- fix build on ppc64 again
- update suppressions
* Fri Aug 24 2007 dmueller@suse.de
- fix valgrind on x86_64 (#296803)
* Tue Aug 21 2007 dmueller@suse.de
- suppression update
* Mon Jul 23 2007 dmueller@suse.de
- update suppression file
* Mon Jul  9 2007 dmueller@suse.de
- support JIT runtimes (#289490)
* Tue Jul  3 2007 dmueller@suse.de
- update suppression file (#287090)
* Wed May 23 2007 dmueller@suse.de
- build against glibc 2.6
* Thu Apr  5 2007 dmueller@suse.de
- split into -devel subpackage
* Fri Mar 30 2007 dmueller@suse.de
- add patch to track undefinedness in environment (#249676)
* Tue Jan 30 2007 dmueller@suse.de
- update to 3.2.3:
  * fixes two serious regressions introduced in 3.2.2
  * intercept stpcpy_chk (#234247)
- fix openat syscall wrapper (#240225)
* Thu Jan 25 2007 dmueller@suse.de
- intercept stpcpy_chk and memrchr as well (#234347)
* Tue Jan 23 2007 dmueller@suse.de
- switch to gcc-32bit on x86_64
* Mon Jan 22 2007 dmueller@suse.de
- update to 3.2.2:
  * many fixes for ppc 32/64 (#fate 301640)
* Tue Oct 17 2006 dmueller@suse.de
- disable omega plugin for ppc/ppc64
* Mon Oct 16 2006 dmueller@suse.de
- update to 3.2 BRANCH:
  * support glibc 2.5
  * update suppressions
- add omega plugin
* Fri Sep 15 2006 dmueller@suse.de
- update to 3.2.1:
  * suppresion updates
* Fri Sep 15 2006 dmueller@suse.de
- update to 3.2.1rc1:
  * about 36 bugfixes
* Wed Sep 13 2006 stbinner@suse.de
- fix build with < Factory
* Mon Aug 28 2006 dmueller@suse.de
- fix suppressions
- update drd plugin
* Thu Aug 24 2006 dmueller@suse.de
- add experimental drd plugin
- fix build on x86_64
* Wed Aug  2 2006 dmueller@suse.de
- also fix multibyte NOP parsing for x86_64
* Tue Aug  1 2006 dmueller@suse.de
- add patch to handle multibyte NOPs as generated by
  recent binutils
* Wed Jun  7 2006 dmueller@suse.de
- update to 3.2.0 final
  * only marginal changes since rc1
* Tue May 30 2006 dmueller@suse.de
- update to 3.2.0 rc1:
  * ppc64 support
  * callgrind now integrated part
  * massive performance improvements
  * lots of emulation fixlets
* Thu Mar 16 2006 dmueller@suse.de
- update to 3.1.1 (FATE #300493)
* Mon Mar  6 2006 dmueller@suse.de
- various updates from branch to fix PPC32 support
* Mon Feb  6 2006 dmueller@suse.de
- Fix GDB support
* Mon Feb  6 2006 dmueller@suse.de
- Reduce BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan  4 2006 dmueller@suse.de
- update to 3.1 branch
* Fri Dec  9 2005 dmueller@suse.de
- fix strict-aliasing issue
* Mon Nov 28 2005 dmueller@suse.de
- 3.1.0 final update
* Mon Nov 21 2005 dmueller@suse.de
- 3.1.0 RC1 update
* Thu Nov 10 2005 dmueller@suse.de
- update to 3.1 SVN
* Tue Nov  8 2005 dmueller@suse.de
- add hack to make valgrind work with apps that require executable stack
* Thu Sep 15 2005 dmueller@suse.de
- update 3.0.1 final
* Wed Aug 24 2005 dmueller@suse.de
- make massif work again
* Sun Aug 21 2005 dmueller@suse.de
- fix trace-children=yes failure
- add default suppressions for SL 10
* Mon Aug 15 2005 dmueller@suse.de
- regenerate VEX offset headers, otherwise it just hangs
* Fri Aug 12 2005 dmueller@suse.de
- update to 3.0 branch to make it work on non-SSE platforms (#104181)
* Fri Aug  5 2005 dmueller@suse.de
- initial package of 3.0
